Changes for bmi-geotiff
=======================

0.3 (2022-08-04)
----------------

- Fix source and binary distributions (#17)
- Switch from xarray to rioxarray (#15)
- Move metadata from setup.cfg to pyproject.toml (#14)
- Use CITATION.cff file (#8)


0.2.3 (2021-05-09)
------------------

- Modify how the BMI treats the projection string variable (#7)


0.2.2 (2021-05-05)
------------------

- Fix shapes in BMI (#6)


0.2.1 (2021-05-05)
------------------

- Add DOI and CITATION document
- Remove dimensions of length 1 (#5)


0.2 (2021-04-22)
----------------

- Add user and API documentation, deplot to Read the Docs (#3)
- Set up CI tasks using GitHub Actions (#4)


0.1 (2021-04-16)
----------------

- Create base library that uses xarray
- Write tests for library
- Implement BMI for GeoTiff class from template generated by `bmipy-render`
- Make demo Jupyter Notebooks
